const filterTableId = "#filterTable";
const filterModalId = "#filterFormModal";


// region Init Module

function initFiltersModule() {
    initializeDataTable(
        filterTableId,
        [
            {
                title: "Name",
                data: "name",
                render: renderEditColumn
            },
            {
                title: "Match",
                data: "match"
            },
            {
                title: "Algorithm",
                data: "matching_algorithm",
                render: function(data) {
                    switch (data) {
                        case 1: return "Any Word";
                        case 2: return "All Words";
                        case 3: return "Exact Match";
                        case 4: return "Regular Expression";
                        case 5: return "Fuzzy Match";
                        default:
                            console.error(`unknown matching algorithm '${data}'`);
                            return data;
                    }

                }
            },
            {
                title: "Case-Sensitive",
                data: "is_insensitive",
                className: "text-center",
                render: data => renderBooleanColumn(!data)
            },
            {
                title: "Type",
                data: "is_whitelist",
                render: data => data ? "Only Allow" : "Reject All"
            }
        ]
    )
}


// region Load Data

$(document).on("selectedServerChange", async function() {
    await loadFilterData();
});

$(filterTableId).on("doDataLoad", async function() {
    await loadFilterData();
});

async function loadFilterData() {
    if (!selectedServer) {
        return;
    }

    setTableFilter(filterTableId, "server", selectedServer.id);
    await loadTableData(filterTableId, "/api/filters/", "GET");
}


// region New/Edit Modal

$(filterTableId).closest('.js-tableBody').siblings('.js-tableFilters').on("click", ".table-new-btn", async function() {
    await openDataModal(filterModalId, -1);
});

$(filterTableId).on("click", ".edit-modal", async function() {
    const id = $(filterTableId).DataTable().row($(this).closest("tr")).data().id;
    await openDataModal(filterModalId, id, `/api/filters/${id}/`);
});

$(filterModalId).on("submit", async function(event) {
    event.preventDefault();
    await onModalSubmit(
        $(filterModalId),
        $(filterTableId),
        "/api/filters/"
    );
});


// region Load Modal Options

$(document).ready(async function() {
    await loadMatchingAlgorithms();
});

async function loadMatchingAlgorithms() {
    const data = await ajaxRequest("/api/filters/", "OPTIONS");
    data.actions.GET.matching_algorithm.choices.forEach(algorithm => {
        $(filterModalId).find('[data-field="matching_algorithm"]').append($(
            "<option>",
            {
                text: algorithm.display_name,
                value: algorithm.value > 0 ? algorithm.value : ""
            }
        ));
    });
}
